@@ -4,12 +4,13 @@ use utf8;
 use strict;
 use warnings;
 use charnames qw( :full );
+use CLDR::Number::Constant qw( $N $M $P $C );
 
 # This module does not have a publicly supported interface and may change in
 # backward incompatible ways in the future. Please use one of the documented
 # classes instead.
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our $DATA = {
     root => {
@@ -3018,13 +3019,6 @@ our $DATA = {
     )
 };
 
-# using non-Unicode codepoints as placeholders:
-# $N: formatted number
-# $P: percent sign
-# $C: currency sign
-# $M: minus sign
-my ($N, $P, $C, $M) = map { chr } 0x1F0000 .. 0x1F0003;
-
 our $CACHE = {
     patterns => {
         '#0%'                         => [ '#0',          "$N$P"             ],
