@@ -6,13 +6,14 @@ use Scalar::Util qw( looks_like_number );
 use Math::BigFloat;
 use Math::Round;
 use Moo::Role;
+use CLDR::Number::Constant qw( $N $M $P $C $Q );
 use CLDR::Number::Data::Base;
 
 # This role does not have a publicly supported interface and may change in
 # backward incompatible ways in the future. Please use one of the documented
 # classes instead.
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 requires qw( BUILD format );
 
@@ -116,17 +117,6 @@ after _trigger_locale => sub {
     $self->_build_pattern;
 };
 
-# using non-Unicode codepoints as placeholders:
-# $N: formatted number
-# $P: percent sign
-# $C: currency sign
-# $M: minus sign
-# $Q: escaped quote sign
-my ($N, $P, $C, $M, $Q) = map { chr } 0x1F0000 .. 0x1F0004;
-# TODO: find better solution for this hack around a Perl ≤ v5.8.8 bug with
-# non-Unicode code points in capture buffers
-my $Q_enc = "\xF7\xB0\x80\x84";
-
 sub _build_pattern {
     my ($self) = @_;
 
@@ -204,8 +194,8 @@ sub _trigger_pattern {
         }
     }
 
-    $internal_pattern  =~ s{ $Q | $Q_enc }{'}xg;
-    $canonical_pattern =~ s{ $Q | $Q_enc }{''}xg;
+    $internal_pattern  =~ s{$Q}{'}g;
+    $canonical_pattern =~ s{$Q}{''}g;
 
     $self->_positive_pattern($internal_pattern);
     $self->_negative_pattern($M . $internal_pattern);
